@@ -61,32 +61,42 @@
 
 /**
  * \def H5FD_SUBFILING_FILENAME_TEMPLATE
- * The basic template for a subfile filename. The format specifiers
- * correspond to:
+ * The basic printf-style template for a #H5FD_SUBFILING driver
+ * subfile filename. The format specifiers correspond to:
  *
- * %s      -> base filename, e.g. "file.h5"
- * %PRIu64 -> file inode, e.g. 11273556
- * %0*d    -> number (starting at 1) signifying the Nth (out of total
- *            number of subfiles) subfile. Zero-padded according
- *            to the number of digits in the number of subfiles
- *            (calculated by log10(num_subfiles) + 1)
- * %d      -> number of subfiles
+ * \par \%s
+ *   base filename, e.g. "file.h5"
+ *
+ * \par \%PRIu64
+ *   file inode, e.g. 11273556
+ *
+ * \par \%0*d
+ *   number (starting at 1) signifying the Nth (out of
+ *   total number of subfiles) subfile. Zero-padded
+ *   according to the number of digits in the number of
+ *   subfiles (calculated by <tt>log10(num_subfiles) + 1)</tt>
+ *
+ * \par \%d
+ *   number of subfiles
  *
  * yielding filenames such as:
  *
- * file.h5.subfile_11273556_01_of_10
- * file.h5.subfile_11273556_02_of_10
- * file.h5.subfile_11273556_10_of_10
+ * file.h5.subfile_11273556_01_of_10 \n
+ * file.h5.subfile_11273556_02_of_10 \n
+ * file.h5.subfile_11273556_10_of_10 \n
  */
 #define H5FD_SUBFILING_FILENAME_TEMPLATE "%s.subfile_%" PRIu64 "_%0*d_of_%d"
 
 /**
  * \def H5FD_SUBFILING_CONFIG_FILENAME_TEMPLATE
- * The basic template for a #H5FD_SUBFILING driver configuration filename.
- * The format specifiers correspond to:
+ * The basic printf-style template for a #H5FD_SUBFILING driver
+ * configuration filename. The format specifiers correspond to:
  *
- * %s      -> base filename, e.g. "file.h5"
- * %PRIu64 -> file inode, e.g. 11273556
+ * \par \%s
+ *   base filename, e.g. "file.h5"
+ *
+ * \par \%PRIu64
+ *   file inode, e.g. 11273556
  *
  * yielding a filename such as:
  *
@@ -148,6 +158,27 @@
  * pathname.
  */
 #define H5FD_SUBFILING_SUBFILE_PREFIX "H5FD_SUBFILING_SUBFILE_PREFIX"
+/**
+ * \def H5FD_SUBFILING_CONFIG_FILE_PREFIX
+ * Macro for name of the environment variable that specifies a prefix
+ * to apply to the subfiling configuration filename. Useful for cases
+ * where the application wants to place the configuration file in a
+ * different directory than the default of putting it alongside the
+ * generated subfiles. For example, when writing to node-local storage
+ * one may wish to place the configuration file on a scratch file
+ * system readable by all nodes, while the subfiles are initially
+ * written to the node-local storage.
+ *
+ * The value set for this environment variable is interpreted as a
+ * pathname that must already exist.
+ *
+ * NOTE: As this prefix string will be encoded in the driver info
+ *       message that gets written to the file, there is an upper
+ *       limit of about ~900 single-byte characters for this string,
+ *       though possibly less due to other information the driver
+ *       may encode. Avoid long prefix names where possible.
+ */
+#define H5FD_SUBFILING_CONFIG_FILE_PREFIX "H5FD_SUBFILING_CONFIG_FILE_PREFIX"
 
 /**
  * \enum H5FD_subfiling_ioc_select_t
@@ -264,10 +295,10 @@ typedef struct H5FD_subfiling_params_t {
  *      the #H5FD_IOC driver by calling H5Pset_fapl_ioc(), but future development
  *      may allow other file drivers to be used.
  *
- * \var hbool_t H5FD_subfiling_config_t::require_ioc
+ * \var bool H5FD_subfiling_config_t::require_ioc
  *      A boolean flag which indicates whether the #H5FD_SUBFILING driver should
  *      use the #H5FD_IOC driver for its I/O operations. This field should currently
- *      always be set to TRUE.
+ *      always be set to true.
  *
  * \var H5FD_subfiling_params_t H5FD_subfiling_config_t::shared_cfg
  *      A structure which contains the subfiling parameters that are shared between
@@ -279,7 +310,7 @@ typedef struct H5FD_subfiling_config_t {
     uint32_t magic;                     /* Must be set to H5FD_SUBFILING_FAPL_MAGIC                         */
     uint32_t version;                   /* Must be set to H5FD_SUBFILING_CURR_FAPL_VERSION                  */
     hid_t    ioc_fapl_id;               /* The FAPL setup with the stacked VFD to use for I/O concentrators */
-    hbool_t  require_ioc;               /* Whether to use the IOC VFD (currently must always be TRUE)       */
+    bool     require_ioc;               /* Whether to use the IOC VFD (currently must always be true)       */
     H5FD_subfiling_params_t shared_cfg; /* Subfiling/IOC parameters (stripe size, stripe count, etc.)       */
 } H5FD_subfiling_config_t;
 //! <!-- [H5FD_subfiling_config_t_snip] -->
